summaryrefslogtreecommitdiff
path: root/gdb/target.h
diff options
context:
space:
mode:
authorYao Qi <yao@codesourcery.com>2011-11-14 14:11:36 +0000
committerYao Qi <yao@codesourcery.com>2011-11-14 14:11:36 +0000
commite8ba31153a46231c6ea664762e633f00256af237 (patch)
treefa7d9d12723b213aa77bd236ca828c0c69267f8f /gdb/target.h
parent9301f9c3e348449d38ecb37b575ffbf4ac37bdde (diff)
downloadbinutils-gdb-e8ba31153a46231c6ea664762e633f00256af237.tar.gz
* target.h (struct target): <to_download_tracepoint> Change type
of parameter from tracepoint to bp_location. * target.c (update_current_target): Update. * tracepoint.c (start_tracing): Update. * remote.c (remote_download_tracepoint): Remove loop for each location of a tracepoint.
Diffstat (limited to 'gdb/target.h')
-rw-r--r--gdb/target.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/gdb/target.h b/gdb/target.h
index 352f2df5b1d..ec7937a53b7 100644
--- a/gdb/target.h
+++ b/gdb/target.h
@@ -686,8 +686,8 @@ struct target_ops
/* Prepare the target for a tracing run. */
void (*to_trace_init) (void);
- /* Send full details of a tracepoint to the target. */
- void (*to_download_tracepoint) (struct breakpoint *t);
+ /* Send full details of a tracepoint location to the target. */
+ void (*to_download_tracepoint) (struct bp_location *location);
/* Send full details of a trace state variable to the target. */
void (*to_download_trace_state_variable) (struct trace_state_variable *tsv);